@@ -6,13 +6,13 @@ sub _clean_eval { eval $_[0] }
 
 use Sub::Defer;
 use Scalar::Util qw(weaken);
-use base qw(Exporter);
+use Exporter qw(import);
 use B ();
 BEGIN {
   *_HAVE_PERLSTRING = defined &B::perlstring ? sub(){1} : sub(){0};
 }
 
-our $VERSION = '1.006000';
+our $VERSION = '1.006001';
 $VERSION = eval $VERSION;
 
 our @EXPORT = qw(quote_sub unquote_sub quoted_from_sub qsub);
